==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/PanePinnedEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { UnpinnedLocation_$type } from "./UnpinnedLocation";
/**
 * @hidden
 */
var PanePinnedEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PanePinnedEventArgsDetail, _super);
    function PanePinnedEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.g = null;
        return _this;
    }
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.d.n = this.g;
        },
        enumerable: false,
        configurable: true
    });
    PanePinnedEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.e.l("sourcePane", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.e.l("panes", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "f", {
        get: function () {
            var ret_ = this.e.m("newValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("newValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "c", {
        get: function () {
            var ret_ = this.e.m("location");
            ret_ = enumGetBox(UnpinnedLocation_$type, EnumUtil.getEnumValue(UnpinnedLocation_$type, this.e.f(UnpinnedLocation_$type, ret_)));
            return EnumUtil.getEnumValue(UnpinnedLocation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(UnpinnedLocation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("location", value_);
        },
        enumerable: false,
        configurable: true
    });
    PanePinnedEventArgsDetail.$t = markType(PanePinnedEventArgsDetail, 'PanePinnedEventArgsDetail');
    return PanePinnedEventArgsDetail;
}(Base));
export { PanePinnedEventArgsDetail };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/PanePinnedEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { UnpinnedLocation_$type } from "./UnpinnedLocation";
/**
 * @hidden
 */
var PanePinnedEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PanePinnedEventArgsDetail, _super);
    function PanePinnedEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.g = null;
        return _this;
    }
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.d.o = this.g;
        },
        enumerable: false,
        configurable: true
    });
    PanePinnedEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.e.m("sourcePane", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.e.m("panes", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "f", {
        get: function () {
            var ret_ = this.e.n("newValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("newValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PanePinnedEventArgsDetail.prototype, "c", {
        get: function () {
            var ret_ = this.e.n("location");
            ret_ = enumGetBox(UnpinnedLocation_$type, EnumUtil.getEnumValue(UnpinnedLocation_$type, this.e.f(UnpinnedLocation_$type, ret_)));
            return EnumUtil.getEnumValue(UnpinnedLocation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(UnpinnedLocation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("location", value_);
        },
        enumerable: false,
        configurable: true
    });
    PanePinnedEventArgsDetail.$t = markType(PanePinnedEventArgsDetail, 'PanePinnedEventArgsDetail');
    return PanePinnedEventArgsDetail;
}(Base));
export { PanePinnedEventArgsDetail };
